@@ -2,7 +2,9 @@
 data.table::setDTthreads(threads = 2L)
 # Set number of collapse threads to 1
 collapse::set_collapse(nthreads = 1L)
+
 options(timeplyr.interval_sub_formatter = identity)
+options(timeplyr.use_intervals = FALSE)
 
 test_that("time breaks", {
   start1 <- lubridate::ymd_hms("2013-03-16 11:43:48",
@@ -110,3 +112,5 @@ test_that("time cut", {
   #                                     n_at_most = TRUE),
   #                            time_cut(x, n = 10^6, time_by = "hour"))
 })
+
+reset_timeplyr_options()
